@@ -7,7 +7,7 @@ from configparser import ConfigParser
 class Config(ConfigParser):
     """Configuration class"""
 
-    common_locatons = [
+    common_locations = [
         os.path.expanduser('~/.showtime.ini')
     ]
 
@@ -15,10 +15,12 @@ class Config(ConfigParser):
         """Loads configuration file"""
         self.add_section('Database')
         self.set('Database', 'Path', str(os.path.join(os.getcwd(), 'showtime.json')))
+
         self.add_section('History')
         self.set('History', 'Path', str(os.path.expanduser('~/.showtime_history')))
+
         if file_name == '':
-            for location in self.common_locatons:
+            for location in self.common_locations:
                 if os.path.exists(location):
                     file_name = location
 
